@@ -12,6 +12,16 @@ sub slurp {
     return @files;
 }
 
+sub run_ack {
+    my @args = @_;
+
+    my $cmd = "$^X -T ./ack-standalone @_";
+    my @results = `$cmd`;
+    chomp @results;
+
+    return @results;
+}
+
 # Use this one if order is important
 sub lists_match {
     my @actual = @{+shift};
@@ -40,20 +50,8 @@ sub sets_match {
     my @expected = @{+shift};
     my $msg = shift;
 
-    # Normalize all the paths
-    for my $path ( @expected, @actual ) {
-        $path = File::Next::reslash( $path ); ## no critic (Variables::ProhibitPackageVars)
-    }
-
     local $Test::Builder::Level = $Test::Builder::Level + 1; ## no critic
-
-    eval 'use Test::Differences';
-    if ( !$@ ) {
-        return eq_or_diff( [sort @actual], [sort @expected], $msg );
-    }
-    else {
-        return is_deeply( [sort @actual], [sort @expected], $msg );
-    }
+    return lists_match( [sort @actual], [sort @expected], $msg );
 }
 
 sub is_filetype {
